Welcome to PySMSBoxNet's documentation!
=======================================

This Python library implement the `SMSBox <https://www.smsbox.net>`_ API.
The main function is to send a SMS but you can also get your remaining credits.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   ./install.rst
   ./pysmsboxnet.rst
   ./example.rst
   ./develop.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
